@@ -1,4 +1,5 @@
 import itertools
+import warnings
 
 import pytest
 from tlz import merge
@@ -8,10 +9,10 @@ np = pytest.importorskip("numpy")
 import dask
 import dask.array as da
 from dask import config
+from dask.array.chunk import getitem
 from dask.array.slicing import (
     _sanitize_index_element,
     _slice_1d,
-    cached_cumsum,
     make_block_sorted_slices,
     new_blockdim,
     normalize_index,
@@ -23,8 +24,6 @@ from dask.array.slicing import (
 )
 from dask.array.utils import assert_eq, same_keys
 
-from ..chunk import getitem
-
 
 def test_slice_1d():
     expected = {0: slice(10, 25, 1), 1: slice(None, None, None), 2: slice(0, 1, 1)}
@@ -359,14 +358,14 @@ def test_take_sorted():
         "y", "x", [(20, 20, 20, 20), (20, 20)], [1, 3, 5, 37], itemsize=8, axis=1
     )
     expected = merge(
-        dict(
-            (("y", i, 0), (getitem, ("x", i, 0), (slice(None, None, None), [1, 3, 5])))
+        {
+            ("y", i, 0): (getitem, ("x", i, 0), (slice(None, None, None), [1, 3, 5]))
             for i in range(4)
-        ),
-        dict(
-            (("y", i, 1), (getitem, ("x", i, 1), (slice(None, None, None), [17])))
+        },
+        {
+            ("y", i, 1): (getitem, ("x", i, 1), (slice(None, None, None), [17]))
             for i in range(4)
-        ),
+        },
     )
     np.testing.assert_equal(dsk, expected)
     assert chunks == ((20, 20, 20, 20), (3, 1))
@@ -785,9 +784,9 @@ def test_slicing_integer_no_warnings():
     # https://github.com/dask/dask/pull/2457/
     X = da.random.random((100, 2), (2, 2))
     idx = np.array([0, 0, 1, 1])
-    with pytest.warns(None) as rec:
+    with warnings.catch_warnings(record=True) as record:
         X[idx].compute()
-    assert len(rec) == 0
+    assert not record
 
 
 @pytest.mark.slow
@@ -888,17 +887,17 @@ def test_getitem_avoids_large_chunks():
 
         # Users can silence the warning
         with dask.config.set({"array.slicing.split-large-chunks": False}):
-            with pytest.warns(None) as e:
+            with warnings.catch_warnings(record=True) as record:
                 result = arr[indexer]
-            assert len(e) == 0
             assert_eq(result, expected)
+            assert not record
 
         # Users can silence the warning
         with dask.config.set({"array.slicing.split-large-chunks": True}):
-            with pytest.warns(None) as e:
+            with warnings.catch_warnings(record=True) as record:
                 result = arr[indexer]
-            assert len(e) == 0  # no
             assert_eq(result, expected)
+            assert not record
 
             assert result.chunks == ((1,) * 12, (128,), (128,))
 
@@ -977,29 +976,6 @@ def test_pathological_unsorted_slicing():
     assert "out-of-order" in str(info.list[0])
 
 
-def test_cached_cumsum():
-    a = (1, 2, 3, 4)
-    x = cached_cumsum(a)
-    y = cached_cumsum(a, initial_zero=True)
-    assert x == (1, 3, 6, 10)
-    assert y == (0, 1, 3, 6, 10)
-
-
-def test_cached_cumsum_nan():
-    a = (1, np.nan, 3)
-    x = cached_cumsum(a)
-    y = cached_cumsum(a, initial_zero=True)
-    np.testing.assert_equal(x, (1, np.nan, np.nan))
-    np.testing.assert_equal(y, (0, 1, np.nan, np.nan))
-
-
-def test_cached_cumsum_non_tuple():
-    a = [1, 2, 3]
-    assert cached_cumsum(a) == (1, 3, 6)
-    a[1] = 4
-    assert cached_cumsum(a) == (1, 5, 8)
-
-
 @pytest.mark.parametrize("params", [(2, 2, 1), (5, 3, 2)])
 def test_setitem_with_different_chunks_preserves_shape(params):
     """Reproducer for https://github.com/dask/dask/issues/3730.
@@ -1065,3 +1041,9 @@ def test_slice_array_3d_with_bool_numpy_array():
     actual = array[mask].compute()
     expected = np.arange(13, 24)
     assert_eq(actual, expected)
+
+
+def test_slice_array_null_dimension():
+    array = da.from_array(np.zeros((3, 0)))
+    expected = np.zeros((3, 0))[[0]]
+    assert_eq(array[[0]], expected)
