@@ -4,17 +4,19 @@ distributed = pytest.importorskip("distributed")
 
 import asyncio
 import os
+import sys
 from functools import partial
 from operator import add
 
-from distributed.utils_test import client as c  # noqa F401
+from distributed.utils_test import cleanup  # noqa F401
 from distributed.utils_test import cluster_fixture  # noqa F401
-from distributed.utils_test import loop  # noqa F401
-from distributed.utils_test import cluster, gen_cluster, inc, varying
+from distributed.utils_test import client as c  # noqa F401
+from distributed.utils_test import cluster, gen_cluster, inc, loop, varying  # noqa F401
 
 import dask
 import dask.bag as db
 from dask import compute, delayed, persist
+from dask.blockwise import Blockwise
 from dask.delayed import Delayed
 from dask.distributed import futures_of, wait
 from dask.highlevelgraph import HighLevelGraph, MaterializedLayer
@@ -25,6 +27,21 @@ if "should_check_state" in get_named_args(gen_cluster):
     cluster = partial(cluster, should_check_state=False)
 
 
+# TODO: the fixture teardown for `cluster_fixture` is failing periodically with
+# a PermissionError on windows only (in CI). Since this fixture lives in the
+# distributed codebase and is nested within other fixtures we use, it's hard to
+# patch it from the dask codebase. And since the error is during fixture
+# teardown, an xfail won't cut it. As a hack, for now we skip all these tests
+# on windows. See https://github.com/dask/dask/issues/8877.
+pytestmark = pytest.mark.skipif(
+    sys.platform == "win32",
+    reason=(
+        "The teardown of distributed.utils_test.cluster_fixture "
+        "fails on windows CI currently"
+    ),
+)
+
+
 def test_can_import_client():
     from dask.distributed import Client  # noqa: F401
 
@@ -77,10 +94,25 @@ def test_futures_to_delayed_dataframe(c):
     ddf = dd.from_delayed(futures)
     dd.utils.assert_eq(ddf.compute(), pd.concat([df, df], axis=0))
 
+    # Make sure from_delayed is Blockwise
+    assert isinstance(ddf.dask.layers[ddf._name], Blockwise)
+
     with pytest.raises(TypeError):
         ddf = dd.from_delayed([1, 2])
 
 
+def test_from_delayed_dataframe(c):
+    # Check that Delayed keys in the form of a tuple
+    # are properly serialized in `from_delayed`
+    pd = pytest.importorskip("pandas")
+    dd = pytest.importorskip("dask.dataframe")
+
+    df = pd.DataFrame({"x": range(20)})
+    ddf = dd.from_pandas(df, npartitions=2)
+    ddf = dd.from_delayed(ddf.to_delayed())
+    dd.utils.assert_eq(ddf, df, scheduler=c)
+
+
 @pytest.mark.parametrize("fuse", [True, False])
 def test_fused_blockwise_dataframe_merge(c, fuse):
     pd = pytest.importorskip("pandas")
@@ -259,7 +291,7 @@ def test_local_scheduler():
         z = await y.persist()
         assert len(z.dask) == 1
 
-    asyncio.get_event_loop().run_until_complete(f())
+    asyncio.run(f())
 
 
 @gen_cluster(client=True)
@@ -454,6 +486,28 @@ def test_blockwise_different_optimization(c):
     np.testing.assert_equal(y_value, expected)
 
 
+def test_blockwise_cull_allows_numpy_dtype_keys(c):
+    # Regression test for https://github.com/dask/dask/issues/9072
+    da = pytest.importorskip("dask.array")
+    np = pytest.importorskip("numpy")
+
+    # Create a multi-block array.
+    x = da.ones((100, 100), chunks=(10, 10))
+
+    # Make a layer that pulls a block out of the array, but
+    # refers to that block using a numpy.int64 for the key rather
+    # than a python int.
+    name = next(iter(x.dask.layers))
+    block = {("block", 0, 0): (name, np.int64(0), np.int64(1))}
+    dsk = HighLevelGraph.from_collections("block", block, [x])
+    arr = da.Array(dsk, "block", ((10,), (10,)), dtype=x.dtype)
+
+    # Stick with high-level optimizations to force serialization of
+    # the blockwise layer.
+    with dask.config.set({"optimization.fuse.active": False}):
+        da.assert_eq(np.ones((10, 10)), arr, scheduler=c)
+
+
 @gen_cluster(client=True)
 async def test_combo_of_layer_types(c, s, a, b):
     """Check pack/unpack of a HLG that has every type of Layers!"""
@@ -723,3 +777,51 @@ async def test_non_recursive_df_reduce(c, s, a, b):
     )
 
     assert (await c.compute(result)).val == 170
+
+
+def test_set_index_no_resursion_error(c):
+    # see: https://github.com/dask/dask/issues/8955
+    pytest.importorskip("dask.dataframe")
+    try:
+        ddf = (
+            dask.datasets.timeseries(start="2000-01-01", end="2000-07-01", freq="12h")
+            .reset_index()
+            .astype({"timestamp": str})
+        )
+        ddf = ddf.set_index("timestamp", sorted=True)
+        ddf.compute()
+    except RecursionError:
+        pytest.fail("dd.set_index triggered a recursion error")
+
+
+@pytest.mark.xfail(reason="https://github.com/dask/dask/issues/8991", strict=True)
+@gen_cluster(client=True)
+async def test_gh_8991(c, s, a, b):
+    # Test illustrating something amiss with HighLevelGraph.key_dependencies.
+    # The intention is for this to be a cache, so if we clear it, things
+    # should still work.
+
+    # This is a bad test, and we should rethink/remove it as soon as the issue is
+    # resolved whether, it's fixing the underlying problem or removing
+    # HighLevelGraph.key_dependencies alltogether.
+    datasets = pytest.importorskip("dask.datasets")
+    result = datasets.timeseries().shuffle("x").to_orc("tmp", compute=False)
+
+    # Create a dsk and mock sending it to the scheduler.
+    dsk_opt = result.__dask_optimize__(result.dask, result.key)
+    unpacked = HighLevelGraph.__dask_distributed_unpack__(
+        dsk_opt.__dask_distributed_pack__(c, result.key)
+    )
+    deps = unpacked["deps"]
+
+    # Create a version of the dsk without the key_dependencies and mock sending it to
+    # the scheduler as well.
+    dsk_opt_nokeys = dsk_opt.copy()
+    dsk_opt_nokeys.key_dependencies.clear()
+    unpacked_nokeys = HighLevelGraph.__dask_distributed_unpack__(
+        dsk_opt_nokeys.__dask_distributed_pack__(c, result.key)
+    )
+    deps_nokeys = unpacked_nokeys["deps"]
+
+    # The recalculated dependencies should still be the same!
+    assert deps == deps_nokeys
